<?php
/**
 * @file
 * Contains \Drupal\google_groups\Form\GroupsBlockForm.
 */
namespace Drupal\google_groups\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Logger\RfcLogLevel;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\google_groups\Services\GoogleGroupsApiClientService;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;

/**
 * Implements an google group form.
 */
class GroupsBlockForm extends FormBase {

  /**
   * @var \Drupal\google_groups\Services\GoogleGroupsApiClientService
   */
  protected $googleGroup;

  /**
   * The logger channel factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactoryInterface
   */
  protected $logger;

  /**
   * {@inheritdoc}
   */
  public function getFormId( ) {
    return 'groups_block_form';
  }

  /**
   * GroupsBlockForm constructor.
   */
  public function __construct( GoogleGroupsApiClientService $googleGroup , LoggerChannelFactoryInterface $logger ) {
    $this->googleGroup = $googleGroup;
    $this->logger = $logger;
  }

  /**
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('google_groups.google_api_services') ,
      $container->get('logger.factory')     
    );  
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['user_email'] = [
      '#type' => 'email',
      '#title' => t('Email ID:'),
      '#required' => TRUE,
    ];

    $form['group_id'] = [
      '#type' => 'hidden'
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Subscribe'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $group_email = $form_state->getValue('group_id');
    $user_email = $form_state->getValue('user_email');
    
    $member = $this->googleGroup->hasMember( $group_email, $user_email )->isMember;
    $log_message = $this->logger->get('google_groups');
    
    if(!$member) {      
      $this->googleGroup->addMember( $user_email, $group_email );
      $log_message->notice('Successfull request, @email added to @group', [
        '@email' => $user_email, 
        '@group' => $group_email, 
      ], RfcLogLevel::INFO);
      $this->messenger()->addStatus($this->t('@email has been added to @group',array('@email' => $user_email, '@group' => $group_email)));
    } 
    else {
      $this->messenger()->addStatus($this->t('@email already belongs to @group',array('@email' => $user_email, '@group' => $group_email)));
    }   
  }
}
