<?php

/**
 * @file
 * Contains \Drupal\google_groups\Plugin\Derivative\GroupsBlock.
 */

namespace Drupal\google_groups\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Provides block plugin definitions for google groups.
 *
 * @see \Drupal\google_groups\Plugin\Block\GroupsBlock
 */
class GroupsBlock extends DeriverBase implements ContainerDeriverInterface  {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * GroupsBlock constructor.
   * 
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */

  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

   /**
   * Gets the definition of all derivatives of a base plugin.
   *
   * @param array $base_plugin_definition
   *   The definition array of the base plugin.
   * @return array
   *   An array of full derivative definitions keyed on derivative id.
   *
   * @see getDerivativeDefinition()
   */
  public function getDerivativeDefinitions($base_plugin_definition) {

    $google = $this->entityTypeManager->getStorage('google_groups');
    $block_urls = $google->loadMultiple();
    $this->derivatives = [];
    foreach ($block_urls as $block_url) {
      $this->derivatives[$block_url->get('group_id')] = $base_plugin_definition;
      $this->derivatives[$block_url->get('group_id')]['admin_label'] = 'Google Groups Block: ' . $block_url->get('group_name');
    }
    return parent::getDerivativeDefinitions($base_plugin_definition);
  }

}
